@@ -2,13 +2,13 @@ import contextlib
 
 import pytest
 
-from pydbm.database import DatabaseManager
+from pydbm.database.manager import DATABASE_EXTENSION, DATABASE_PATH
 
 
 @pytest.fixture(scope="function", autouse=True)
 def teardown_db():
     yield
-    for path in DatabaseManager.database_path.glob("*.db"):
+    for path in DATABASE_PATH.glob(f"*.{DATABASE_EXTENSION}"):
         path.unlink()
 
 
@@ -16,8 +16,8 @@ def teardown_db():
 def _():
     yield
 
-    for path in DatabaseManager.database_path.glob("*.db"):
+    for path in DATABASE_PATH.glob(f"*.{DATABASE_EXTENSION}"):
         path.unlink()
 
     with contextlib.suppress(FileNotFoundError):
-        DatabaseManager.database_path.rmdir()
+        DATABASE_PATH.rmdir()
